@@ -1,23 +1,42 @@
 var annotated_dup =
 [
     [ "buffer", "structbuffer.html", "structbuffer" ],
+    [ "client", "structclient.html", "structclient" ],
+    [ "client_data", "structclient__data.html", "structclient__data" ],
     [ "control", "structcontrol.html", "structcontrol" ],
     [ "data", "structdata.html", "structdata" ],
     [ "error_data", "structerror__data.html", "structerror__data" ],
+    [ "factory_data", "structfactory__data.html", "structfactory__data" ],
     [ "filter", "structfilter.html", "structfilter" ],
+    [ "find_node", "structfind__node.html", "structfind__node" ],
+    [ "find_port", "structfind__port.html", "structfind__port" ],
+    [ "graph", "structgraph.html", "structgraph" ],
+    [ "graph_hndl", "structgraph__hndl.html", "structgraph__hndl" ],
+    [ "graph_port", "structgraph__port.html", "structgraph__port" ],
     [ "handle", "structhandle.html", "structhandle" ],
     [ "impl", "structimpl.html", "structimpl" ],
+    [ "item", "structitem.html", "structitem" ],
+    [ "ladspa_descriptor", "structladspa__descriptor.html", "structladspa__descriptor" ],
+    [ "ladspa_handle", "structladspa__handle.html", "structladspa__handle" ],
+    [ "link", "structlink.html", "structlink" ],
+    [ "link_data", "structlink__data.html", "structlink__data" ],
     [ "log_ctx", "structlog__ctx.html", "structlog__ctx" ],
     [ "mapping", "structmapping.html", "structmapping" ],
     [ "memblock", "structmemblock.html", "structmemblock" ],
     [ "memmap", "structmemmap.html", "structmemmap" ],
     [ "mempool", "structmempool.html", "structmempool" ],
+    [ "metadata", "structmetadata.html", "structmetadata" ],
+    [ "module_roc_sink_data", "structmodule__roc__sink__data.html", "structmodule__roc__sink__data" ],
+    [ "module_roc_source_data", "structmodule__roc__source__data.html", "structmodule__roc__source__data" ],
+    [ "node", "structnode.html", "structnode" ],
+    [ "node_data", "structnode__data.html", "structnode__data" ],
     [ "object_data", "structobject__data.html", "structobject__data" ],
     [ "object_entry", "structobject__entry.html", "structobject__entry" ],
     [ "param", "structparam.html", "structparam" ],
     [ "param_filter", "structparam__filter.html", "structparam__filter" ],
     [ "plugin", "structplugin.html", "structplugin" ],
     [ "port", "structport.html", "structport" ],
+    [ "protocol_data", "structprotocol__data.html", "structprotocol__data" ],
     [ "pw_array", "structpw__array.html", "structpw__array" ],
     [ "pw_buffer", "structpw__buffer.html", "structpw__buffer" ],
     [ "pw_buffers", "structpw__buffers.html", "structpw__buffers" ],
@@ -45,6 +64,7 @@ var annotated_dup =
     [ "pw_impl_factory_events", "structpw__impl__factory__events.html", "structpw__impl__factory__events" ],
     [ "pw_impl_factory_implementation", "structpw__impl__factory__implementation.html", "structpw__impl__factory__implementation" ],
     [ "pw_impl_link_events", "structpw__impl__link__events.html", "structpw__impl__link__events" ],
+    [ "pw_impl_metadata_events", "structpw__impl__metadata__events.html", "structpw__impl__metadata__events" ],
     [ "pw_impl_module_events", "structpw__impl__module__events.html", "structpw__impl__module__events" ],
     [ "pw_impl_node_events", "structpw__impl__node__events.html", "structpw__impl__node__events" ],
     [ "pw_impl_port_events", "structpw__impl__port__events.html", "structpw__impl__port__events" ],
@@ -84,12 +104,17 @@ var annotated_dup =
     [ "pw_stream_events", "structpw__stream__events.html", "structpw__stream__events" ],
     [ "pw_thread_loop_events", "structpw__thread__loop__events.html", "structpw__thread__loop__events" ],
     [ "pw_time", "structpw__time.html", "structpw__time" ],
+    [ "pwtest_context", "structpwtest__context.html", null ],
+    [ "pwtest_spa_plugin", "structpwtest__spa__plugin.html", "structpwtest__spa__plugin" ],
+    [ "pwtest_suite", "structpwtest__suite.html", null ],
+    [ "pwtest_test", "structpwtest__test.html", null ],
     [ "queue", "structqueue.html", "structqueue" ],
     [ "registry", "structregistry.html", "structregistry" ],
     [ "resource_data", "structresource__data.html", "structresource__data" ],
     [ "result_device_params_data", "structresult__device__params__data.html", "structresult__device__params__data" ],
     [ "result_node_params_data", "structresult__node__params__data.html", "structresult__node__params__data" ],
     [ "result_port_params_data", "structresult__port__params__data.html", "structresult__port__params__data" ],
+    [ "server", "structserver.html", "structserver" ],
     [ "spa_audio_info", "structspa__audio__info.html", "structspa__audio__info" ],
     [ "spa_audio_info_dsp", "structspa__audio__info__dsp.html", "structspa__audio__info__dsp" ],
     [ "spa_audio_info_raw", "structspa__audio__info__raw.html", "structspa__audio__info__raw" ],
@@ -203,6 +228,7 @@ var annotated_dup =
     [ "spa_point", "structspa__point.html", "structspa__point" ],
     [ "spa_poll_event", "structspa__poll__event.html", "structspa__poll__event" ],
     [ "spa_port_info", "structspa__port__info.html", "structspa__port__info" ],
+    [ "spa_process_latency_info", "structspa__process__latency__info.html", "structspa__process__latency__info" ],
     [ "spa_rectangle", "structspa__rectangle.html", "structspa__rectangle" ],
     [ "spa_region", "structspa__region.html", "structspa__region" ],
     [ "spa_result_device_params", "structspa__result__device__params.html", "structspa__result__device__params" ],
@@ -223,5 +249,7 @@ var annotated_dup =
     [ "spa_video_info_mjpg", "structspa__video__info__mjpg.html", "structspa__video__info__mjpg" ],
     [ "spa_video_info_raw", "structspa__video__info__raw.html", "structspa__video__info__raw" ],
     [ "stream", "structstream.html", "structstream" ],
-    [ "support", "structsupport.html", "structsupport" ]
+    [ "support", "structsupport.html", "structsupport" ],
+    [ "tunnel", "structtunnel.html", "structtunnel" ],
+    [ "tunnel_info", "structtunnel__info.html", "structtunnel__info" ]
 ];
\ No newline at end of file
